@@ -63,11 +63,6 @@ class AKONADI_EXPORT Entity
      */
     typedef qint64 Id;
 
-    /**
-     * Destroys the entity.
-     */
-    ~Entity();
-
     /**
      * Sets the unique @p identifier of the entity.
      */
@@ -88,6 +83,25 @@ class AKONADI_EXPORT Entity
      */
     QString remoteId() const;
 
+    /**
+     * Sets the remote @p revision of the entity.
+     *
+     * The remote revision can be used by resources to store some
+     * revision information of the backend to detect changes there.
+     *
+     * @note This method is supposed to be used by resources only.
+     * @since 4.5
+     */
+    void setRemoteRevision( const QString& revision );
+
+    /**
+     * Returns the remote revision of the entity.
+     *
+     * @note This method is supposed to be used by resources only.
+     * @since 4.5
+     */
+    QString remoteRevision() const;
+
     /**
      * Returns whether the entity is valid.
      */
@@ -110,6 +124,13 @@ class AKONADI_EXPORT Entity
      */
     Entity& operator=( const Entity &other );
 
+    /**
+     * @internal For use with containers only.
+     *
+     * @since 4.8
+     */
+    bool operator<( const Entity &other ) const;
+
     /**
      * Returns the parent collection of this object.
      * @note This will of course only return a useful value if it was explictly retrieved
@@ -249,6 +270,11 @@ class AKONADI_EXPORT Entity
      */
     Entity( const Entity &other );
 
+    /**
+     * Destroys the entity.
+     */
+    ~Entity();
+
     //@cond PRIVATE
     Entity( EntityPrivate *dd );
     QSharedDataPointer<EntityPrivate> d_ptr;
