@@ -97,12 +97,25 @@ void EntityMimeTypeFilterModel::addMimeTypeExclusionFilter(const QString &type)
   invalidateFilter();
 }
 
+bool EntityMimeTypeFilterModel::filterAcceptsColumn( int sourceColumn, const QModelIndex &sourceParent ) const
+{
+    if (sourceColumn >= columnCount(mapFromSource(sourceParent)))
+        return false;
+    return QSortFilterProxyModel::filterAcceptsColumn( sourceColumn, sourceParent );
+}
+
 bool EntityMimeTypeFilterModel::filterAcceptsRow( int sourceRow, const QModelIndex &sourceParent) const
 {
   Q_D(const EntityMimeTypeFilterModel);
-
   const QModelIndex idx = sourceModel()->index(sourceRow, 0, sourceParent);
 
+  const Akonadi::Item item = idx.data( EntityTreeModel::ItemRole ).value<Akonadi::Item>();
+
+  if ( item.isValid() && !item.hasPayload() ) {
+    kDebug() << "Item " << item.id() << " doesn't have payload";
+    return false;
+  }
+
   const QString rowMimetype = idx.data( EntityTreeModel::MimeTypeRole ).toString();
 
   if ( d->excludedMimeTypes.contains( rowMimetype ) )
