@@ -19,6 +19,7 @@
 
 #include "specialcollectionshelperjobs_p.h"
 
+#include "dbusconnectionpool.h"
 #include "specialcollectionattribute_p.h"
 #include "specialcollections.h"
 
@@ -44,7 +45,7 @@
 #include <QtCore/QTimer>
 
 #define DBUS_SERVICE_NAME QLatin1String( "org.kde.pim.SpecialCollections" )
-#define LOCK_WAIT_TIMEOUT_SECONDS 3
+#define LOCK_WAIT_TIMEOUT_SECONDS 10
 
 using namespace Akonadi;
 
@@ -173,12 +174,12 @@ void ResourceScanJob::setResourceId( const QString &resourceId )
   d->mResourceId = resourceId;
 }
 
-Collection ResourceScanJob::rootResourceCollection() const
+Akonadi::Collection ResourceScanJob::rootResourceCollection() const
 {
   return d->mRootCollection;
 }
 
-Collection::List ResourceScanJob::specialCollections() const
+Akonadi::Collection::List ResourceScanJob::specialCollections() const
 {
   return d->mSpecialCollections;
 }
@@ -197,7 +198,7 @@ void ResourceScanJob::doStart()
                                                          CollectionFetchJob::Recursive, this );
   fetchJob->fetchScope().setResource( d->mResourceId );
   fetchJob->fetchScope().setIncludeStatistics( true );
-  connect( fetchJob, SIGNAL( result( KJob* ) ), this, SLOT( fetchResult( KJob* ) ) );
+  connect( fetchJob, SIGNAL(result(KJob*)), this, SLOT(fetchResult(KJob*)) );
 }
 
 
@@ -251,7 +252,11 @@ void DefaultResourceJobPrivate::tryFetchResource()
     mResourceWasPreexisting = true;
     kDebug() << "Found resource" << resourceId;
     q->setResourceId( resourceId );
-    q->ResourceScanJob::doStart();
+
+    CollectionFetchJob *fetchJob = new CollectionFetchJob( Collection::root(), CollectionFetchJob::Recursive, q );
+    fetchJob->fetchScope().setResource( resourceId );
+    fetchJob->fetchScope().setIncludeStatistics( true );
+    q->connect( fetchJob, SIGNAL(result(KJob*)), q, SLOT(collectionFetchResult(KJob*)) );
   } else {
     // Try harder: maybe the default resource has been removed and another one added
     //             without updating the config file, in this case search for a resource
@@ -277,7 +282,7 @@ void DefaultResourceJobPrivate::tryFetchResource()
     kDebug() << "Creating maildir resource.";
     const AgentType type = AgentManager::self()->type( mDefaultResourceType );
     AgentInstanceCreateJob *job = new AgentInstanceCreateJob( type, q );
-    QObject::connect( job, SIGNAL( result( KJob* ) ), q, SLOT( resourceCreateResult( KJob* ) ) );
+    QObject::connect( job, SIGNAL(result(KJob*)), q, SLOT(resourceCreateResult(KJob*)) );
     job->start(); // non-Akonadi::Job
   }
 }
@@ -345,13 +350,15 @@ void DefaultResourceJobPrivate::resourceCreateResult( KJob *job )
       }
     }
 
+    conf.call( QLatin1String( "writeConfig" ) );
+
     agent.reconfigure();
   }
 
   // Sync the resource.
   {
     ResourceSynchronizationJob *syncJob = new ResourceSynchronizationJob( agent, q );
-    QObject::connect( syncJob, SIGNAL( result( KJob* ) ), q, SLOT( resourceSyncResult( KJob* ) ) );
+    QObject::connect( syncJob, SIGNAL(result(KJob*)), q, SLOT(resourceSyncResult(KJob*)) );
     syncJob->start(); // non-Akonadi
   }
 }
@@ -368,7 +375,7 @@ void DefaultResourceJobPrivate::resourceSyncResult( KJob *job )
   kDebug() << "Fetching maildir collections.";
   CollectionFetchJob *fetchJob = new CollectionFetchJob( Collection::root(), CollectionFetchJob::Recursive, q );
   fetchJob->fetchScope().setResource( defaultResourceId( mSettings ) );
-  QObject::connect( fetchJob, SIGNAL( result( KJob* ) ), q, SLOT( collectionFetchResult( KJob* ) ) );
+  QObject::connect( fetchJob, SIGNAL(result(KJob*)), q, SLOT(collectionFetchResult(KJob*)) );
 }
 
 void DefaultResourceJobPrivate::collectionFetchResult( KJob *job )
@@ -421,6 +428,9 @@ void DefaultResourceJobPrivate::collectionFetchResult( KJob *job )
   Q_ASSERT( mPendingModifyJobs == 0 );
   foreach ( Collection collection, toRecover ) {          // krazy:exclude=foreach
 
+    if ( collection.hasAttribute<SpecialCollectionAttribute>() )
+      continue;
+
     // Find the type for the collection.
     QString name = collection.name();
     if ( collection.hasAttribute<EntityDisplayAttribute>() ) {
@@ -435,7 +445,7 @@ void DefaultResourceJobPrivate::collectionFetchResult( KJob *job )
       setCollectionAttributes( collection, type, mNameForTypeMap, mIconForTypeMap );
 
       CollectionModifyJob *modifyJob = new CollectionModifyJob( collection, q );
-      QObject::connect( modifyJob, SIGNAL( result( KJob* ) ), q, SLOT( collectionModifyResult( KJob* ) ) );
+      QObject::connect( modifyJob, SIGNAL(result(KJob*)), q, SLOT(collectionModifyResult(KJob*)) );
       mPendingModifyJobs++;
     } else {
       kDebug() << "Searching for names: " << typeForName.keys();
@@ -443,8 +453,11 @@ void DefaultResourceJobPrivate::collectionFetchResult( KJob *job )
     }
   }
 
-  if ( mPendingModifyJobs == 0 )
-    q->emitResult();
+  if ( mPendingModifyJobs == 0 ) {
+    // Scan the resource.
+    q->setResourceId( defaultResourceId( mSettings ) );
+    q->ResourceScanJob::doStart();
+  }
 }
 
 void DefaultResourceJobPrivate::collectionModifyResult( KJob *job )
@@ -556,7 +569,7 @@ void GetLockJob::Private::doStart()
   // Just doing registerService() and checking its return value is not sufficient,
   // since we may *already* own the name, and then registerService() returns true.
 
-  QDBusConnection bus = QDBusConnection::sessionBus();
+  QDBusConnection bus = DBusConnectionPool::threadConnection();
   const bool alreadyLocked = bus.interface()->isServiceRegistered( DBUS_SERVICE_NAME );
   const bool gotIt = bus.registerService( DBUS_SERVICE_NAME );
 
@@ -564,24 +577,24 @@ void GetLockJob::Private::doStart()
     //kDebug() << "Got lock immediately.";
     q->emitResult();
   } else {
-    QDBusServiceWatcher *watcher = new QDBusServiceWatcher( DBUS_SERVICE_NAME, QDBusConnection::sessionBus(),
+    QDBusServiceWatcher *watcher = new QDBusServiceWatcher( DBUS_SERVICE_NAME, DBusConnectionPool::threadConnection(),
                                                             QDBusServiceWatcher::WatchForOwnerChange, q );
     //kDebug() << "Waiting for lock.";
-    connect( watcher, SIGNAL( serviceOwnerChanged( const QString&, const QString&, const QString& ) ),
-             q, SLOT( serviceOwnerChanged( const QString&, const QString&, const QString& ) ) );
+    connect( watcher, SIGNAL(serviceOwnerChanged(QString,QString,QString)),
+             q, SLOT(serviceOwnerChanged(QString,QString,QString)) );
 
     mSafetyTimer = new QTimer( q );
     mSafetyTimer->setSingleShot( true );
     mSafetyTimer->setInterval( LOCK_WAIT_TIMEOUT_SECONDS * 1000 );
     mSafetyTimer->start();
-    connect( mSafetyTimer, SIGNAL( timeout() ), q, SLOT( timeout() ) );
+    connect( mSafetyTimer, SIGNAL(timeout()), q, SLOT(timeout()) );
   }
 }
 
 void GetLockJob::Private::serviceOwnerChanged( const QString&, const QString&, const QString &newOwner )
 {
   if ( newOwner.isEmpty() ) {
-    const bool gotIt = QDBusConnection::sessionBus().registerService( DBUS_SERVICE_NAME );
+    const bool gotIt = DBusConnectionPool::threadConnection().registerService( DBUS_SERVICE_NAME );
     if ( gotIt ) {
       mSafetyTimer->stop();
       q->emitResult();
@@ -591,7 +604,7 @@ void GetLockJob::Private::serviceOwnerChanged( const QString&, const QString&, c
 
 void GetLockJob::Private::timeout()
 {
-  kWarning() << "Timeout trying to get lock.";
+  kWarning() << "Timeout trying to get lock. Check who has acquired the name" << DBUS_SERVICE_NAME << "on DBus, using qdbus or qdbusviewer.";
   q->setError( Job::Unknown );
   q->setErrorText( i18n( "Timeout trying to get lock." ) );
   q->emitResult();
@@ -611,7 +624,7 @@ GetLockJob::~GetLockJob()
 
 void GetLockJob::start()
 {
-  QTimer::singleShot( 0, this, SLOT( doStart() ) );
+  QTimer::singleShot( 0, this, SLOT(doStart()) );
 }
 
 void Akonadi::setCollectionAttributes( Akonadi::Collection &collection, const QByteArray &type,
@@ -634,7 +647,7 @@ void Akonadi::setCollectionAttributes( Akonadi::Collection &collection, const QB
 
 bool Akonadi::releaseLock()
 {
-  return QDBusConnection::sessionBus().unregisterService( DBUS_SERVICE_NAME );
+  return DBusConnectionPool::threadConnection().unregisterService( DBUS_SERVICE_NAME );
 }
 
 #include "specialcollectionshelperjobs_p.moc"
