@@ -60,9 +60,9 @@ void ResourceSchedulerTest::testChangeReplaySchedule()
   ResourceScheduler scheduler;
   scheduler.setOnline( true );
   qRegisterMetaType<Akonadi::Collection>("Akonadi::Collection");
-  QSignalSpy changeReplaySpy( &scheduler, SIGNAL( executeChangeReplay() ) );
-  QSignalSpy collectionTreeSyncSpy( &scheduler, SIGNAL( executeCollectionTreeSync() ) );
-  QSignalSpy syncSpy( &scheduler, SIGNAL( executeCollectionSync( const Akonadi::Collection & ) ) );
+  QSignalSpy changeReplaySpy( &scheduler, SIGNAL(executeChangeReplay()) );
+  QSignalSpy collectionTreeSyncSpy( &scheduler, SIGNAL(executeCollectionTreeSync()) );
+  QSignalSpy syncSpy( &scheduler, SIGNAL(executeCollectionSync(Akonadi::Collection)) );
   QVERIFY( changeReplaySpy.isValid() );
   QVERIFY( collectionTreeSyncSpy.isValid() );
   QVERIFY( syncSpy.isValid() );
@@ -78,7 +78,7 @@ void ResourceSchedulerTest::testChangeReplaySchedule()
   scheduler.taskDone();
   QTest::qWait( 1 );
   QCOMPARE( changeReplaySpy.count(), 1 );
-  
+
   // Schedule two change replays. The duplicate one should not be executed.
   changeReplaySpy.clear();
   scheduler.scheduleChangeReplay();
@@ -145,6 +145,11 @@ void ResourceSchedulerTest::testChangeReplaySchedule()
 }
 
 
+void ResourceSchedulerTest::customTaskNoArg()
+{
+  ++mCustomCallCount;
+}
+
 void ResourceSchedulerTest::customTask(const QVariant& argument)
 {
   ++mCustomCallCount;
@@ -161,6 +166,7 @@ void ResourceSchedulerTest::testCustomTask()
   scheduler.scheduleCustomTask( this, "customTask", QString( "call1" ) );
   scheduler.scheduleCustomTask( this, "customTask", QString( "call1" ) );
   scheduler.scheduleCustomTask( this, "customTask", QString( "call2" ) );
+  scheduler.scheduleCustomTask( this, "customTaskNoArg", QVariant() );
 
   QCOMPARE( mCustomCallCount, 0 );
 
@@ -174,6 +180,11 @@ void ResourceSchedulerTest::testCustomTask()
   QCOMPARE( mCustomCallCount, 2 );
   QCOMPARE( mLastArgument.toString(), QString( "call2" ) );
 
+  scheduler.taskDone();
+  QVERIFY( !scheduler.isEmpty() );
+  QTest::qWait( 1 );
+  QCOMPARE( mCustomCallCount, 3 );
+
   scheduler.taskDone();
   QVERIFY( scheduler.isEmpty() );
 }
@@ -186,7 +197,7 @@ void ResourceSchedulerTest::testCompression()
   qRegisterMetaType<Akonadi::Item>( "Akonadi::Item" );
   QSignalSpy fullSyncSpy( &scheduler, SIGNAL(executeFullSync()) );
   QSignalSpy collectionTreeSyncSpy( &scheduler, SIGNAL(executeCollectionTreeSync()) );
-  QSignalSpy syncSpy( &scheduler, SIGNAL(executeCollectionSync(Akonadi::Collection) ) );
+  QSignalSpy syncSpy( &scheduler, SIGNAL(executeCollectionSync(Akonadi::Collection)) );
   QSignalSpy fetchSpy( &scheduler, SIGNAL(executeItemFetch(Akonadi::Item,QSet<QByteArray>)) );
   QVERIFY( fullSyncSpy.isValid() );
   QVERIFY( collectionTreeSyncSpy.isValid() );
@@ -266,7 +277,7 @@ void ResourceSchedulerTest::testSyncCompletion()
   scheduler.taskDone();
   QTest::qWait( 1 );
   QCOMPARE( completionSpy.count(), 3 );
-  scheduler.taskDone(); 
+  scheduler.taskDone();
   QVERIFY( scheduler.isEmpty() );
 }
 
@@ -276,21 +287,24 @@ void ResourceSchedulerTest::testPriorities()
   scheduler.setOnline( true );
   qRegisterMetaType<Akonadi::Collection>("Akonadi::Collection");
   qRegisterMetaType<Akonadi::Item>( "Akonadi::Item" );
-  QSignalSpy changeReplaySpy( &scheduler, SIGNAL( executeChangeReplay() ) );
+  QSignalSpy changeReplaySpy( &scheduler, SIGNAL(executeChangeReplay()) );
   QSignalSpy fullSyncSpy( &scheduler, SIGNAL(executeFullSync()) );
   QSignalSpy collectionTreeSyncSpy( &scheduler, SIGNAL(executeCollectionTreeSync()) );
-  QSignalSpy syncSpy( &scheduler, SIGNAL(executeCollectionSync(Akonadi::Collection) ) );
+  QSignalSpy syncSpy( &scheduler, SIGNAL(executeCollectionSync(Akonadi::Collection)) );
   QSignalSpy fetchSpy( &scheduler, SIGNAL(executeItemFetch(Akonadi::Item,QSet<QByteArray>)) );
+  QSignalSpy attributesSyncSpy( &scheduler, SIGNAL(executeCollectionAttributesSync(Akonadi::Collection)) );
   QVERIFY( changeReplaySpy.isValid() );
   QVERIFY( fullSyncSpy.isValid() );
   QVERIFY( collectionTreeSyncSpy.isValid() );
   QVERIFY( syncSpy.isValid() );
   QVERIFY( fetchSpy.isValid() );
+  QVERIFY( attributesSyncSpy.isValid() );
 
   scheduler.scheduleCollectionTreeSync();
   scheduler.scheduleChangeReplay();
   scheduler.scheduleSync( Akonadi::Collection( 42 ) );
   scheduler.scheduleItemFetch( Akonadi::Item( 42 ), QSet<QByteArray>(), QDBusMessage() );
+  scheduler.scheduleAttributesSync( Akonadi::Collection( 42 ) );
   scheduler.scheduleFullSync();
 
   QTest::qWait( 1 );
@@ -299,6 +313,7 @@ void ResourceSchedulerTest::testPriorities()
   QCOMPARE( syncSpy.count(), 0 );
   QCOMPARE( fullSyncSpy.count(), 0 );
   QCOMPARE( fetchSpy.count(), 0 );
+  QCOMPARE( attributesSyncSpy.count(), 0 );
   scheduler.taskDone();
 
   QTest::qWait( 1 );
@@ -307,6 +322,7 @@ void ResourceSchedulerTest::testPriorities()
   QCOMPARE( syncSpy.count(), 0 );
   QCOMPARE( fullSyncSpy.count(), 0 );
   QCOMPARE( fetchSpy.count(), 1 );
+  QCOMPARE( attributesSyncSpy.count(), 0 );
   scheduler.taskDone();
 
   QTest::qWait( 1 );
@@ -315,6 +331,7 @@ void ResourceSchedulerTest::testPriorities()
   QCOMPARE( syncSpy.count(), 0 );
   QCOMPARE( fullSyncSpy.count(), 0 );
   QCOMPARE( fetchSpy.count(), 1 );
+  QCOMPARE( attributesSyncSpy.count(), 0 );
   scheduler.taskDone();
 
   QTest::qWait( 1 );
@@ -323,6 +340,16 @@ void ResourceSchedulerTest::testPriorities()
   QCOMPARE( syncSpy.count(), 1 );
   QCOMPARE( fullSyncSpy.count(), 0 );
   QCOMPARE( fetchSpy.count(), 1 );
+  QCOMPARE( attributesSyncSpy.count(), 0 );
+  scheduler.taskDone();
+
+  QTest::qWait( 1 );
+  QCOMPARE( collectionTreeSyncSpy.count(), 1 );
+  QCOMPARE( changeReplaySpy.count(), 1 );
+  QCOMPARE( syncSpy.count(), 1 );
+  QCOMPARE( fullSyncSpy.count(), 0 );
+  QCOMPARE( fetchSpy.count(), 1 );
+  QCOMPARE( attributesSyncSpy.count(), 1 );
   scheduler.taskDone();
 
   QTest::qWait( 1 );
@@ -331,6 +358,7 @@ void ResourceSchedulerTest::testPriorities()
   QCOMPARE( syncSpy.count(), 1 );
   QCOMPARE( fullSyncSpy.count(), 1 );
   QCOMPARE( fetchSpy.count(), 1 );
+  QCOMPARE( attributesSyncSpy.count(), 1 );
   scheduler.taskDone();
 
   QVERIFY( scheduler.isEmpty() );
