@@ -54,7 +54,8 @@ using namespace KABC;
 bool LDIFConverter::addresseeToLDIF( const AddresseeList &addrList, QString &str )
 {
   AddresseeList::ConstIterator it;
-  for ( it = addrList.begin(); it != addrList.end(); ++it ) {
+  AddresseeList::ConstIterator end( addrList.constEnd() );
+  for ( it = addrList.constBegin(); it != end; ++it ) {
     addresseeToLDIF( *it, str );
   }
   return true;
@@ -67,7 +68,7 @@ static void ldif_out( QTextStream &t, const QString &formatStr,
     return;
   }
 
-  QByteArray txt = Ldif::assembleLine( formatStr, value, 72 );
+  const QByteArray txt = Ldif::assembleLine( formatStr, value, 72 );
 
   // write the string
   t << QString::fromUtf8( txt ) << "\n";
@@ -122,11 +123,10 @@ bool LDIFConverter::addresseeToLDIF( const Addressee &addr, QString &str )
   ldif_out( t, QLatin1String( "postofficebox" ), workAddr.postOfficeBox() );
 
   QStringList streets = homeAddr.street().split( QLatin1Char( '\n' ) );
-  const int numberOfStreets(streets.count());
-  if ( numberOfStreets > 0 ) {
+  if ( streets.count() > 0 ) {
     ldif_out( t, QLatin1String( "homepostaladdress" ), streets[ 0 ] ); // Netscape 7
   }
-  if ( numberOfStreets > 1 ) {
+  if ( streets.count() > 1 ) {
     ldif_out( t, QLatin1String( "mozillahomepostaladdress2" ), streets[ 1 ] ); // Netscape 7
   }
   ldif_out( t, QLatin1String( "mozillahomelocalityname" ), homeAddr.locality() ); // Netscape 7
@@ -224,7 +224,7 @@ bool LDIFConverter::LDIFToAddressee( const QString &str, AddresseeList &addrList
       {
         QString fieldname = ldif.attr().toLower();
         QString value = QString::fromUtf8( ldif.value(), ldif.value().size() );
-        evaluatePair( a, homeAddr, workAddr, fieldname, value, birthday, birthmonth,birthyear );
+        evaluatePair( a, homeAddr, workAddr, fieldname, value, birthday, birthmonth, birthyear );
         break;
       }
       case Ldif::EndEntry:
@@ -271,7 +271,8 @@ bool LDIFConverter::LDIFToAddressee( const QString &str, AddresseeList &addrList
 
 bool LDIFConverter::evaluatePair( Addressee &a, Address &homeAddr,
                                   Address &workAddr,
-                                  QString &fieldname, QString &value, int &birthday, int &birthmonth, int &birthyear )
+                                  QString &fieldname, QString &value,
+                                  int &birthday, int &birthmonth, int &birthyear )
 {
   if ( fieldname == QLatin1String( "dn" ) ) { // ignore & return false!
     return false;
@@ -357,7 +358,7 @@ addComment:
 
   if ( fieldname == QLatin1String( "homeurl" ) ||
        fieldname == QLatin1String( "workurl" ) ||
-       fieldname == QLatin1String( "mozillahomeurl" )) {
+       fieldname == QLatin1String( "mozillahomeurl" ) ) {
     if ( a.url().isEmpty() ) {
       a.setUrl( KUrl( value ) );
       return true;
@@ -406,8 +407,7 @@ addComment:
   }
 
   if ( fieldname == QLatin1String( "street" ) ||
-       fieldname == QLatin1String( "streethomeaddress" ) ||
-       fieldname == QLatin1String( "mozillahomestreet" ) /*thunderbird*/ ) {
+       fieldname == QLatin1String( "streethomeaddress" ) ) {
     homeAddr.setStreet( value );
     return true;
   }
