@@ -3,6 +3,7 @@
 
   Copyright (c) 2001-2003 Cornelius Schumacher <schumacher@kde.org>
   Copyright (c) 2003 David Jarvie <software@astrojar.org.uk>
+  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -62,7 +63,7 @@ class Incidence;
 
   Alarms always belong to a parent Incidence.
 */
-class KCAL_EXPORT Alarm : public CustomProperties
+class KCAL_EXPORT_DEPRECATED Alarm : public CustomProperties
 {
   public:
     /**
@@ -104,6 +105,12 @@ class KCAL_EXPORT Alarm : public CustomProperties
     */
     virtual ~Alarm();
 
+    /**
+      Assignment operator.
+      @since 4.5
+    */
+    Alarm &operator=( const Alarm & );
+
     /**
       Compares two alarms for equality.
       @param a is the comparison alarm.
